@@ -10,8 +10,6 @@
 NULL
 
 if (getRversion() >= "2.15.1") {
-  vars <- c(
-    ".", ":=", "value", "dotI", "period", "period_start_day"
-  )
+  vars <- c(".", ":=", "value", "dotI", "period", "period_start_day")
   utils::globalVariables(unique(vars))
 }
\ No newline at end of file
